@@ -1,14 +1,14 @@
+lift <- function(x, ...) UseMethod("lift")
 
+lift.default <- function(x, ...) stop("'x' should be a formula")
 
-lift <- function(x, data = NULL, class = NULL, cuts = 11, subset = TRUE, lattice.options = NULL,
-                 ylabel = "% Samples Found", xlabel = "% Samples Tested", ...)
+lift.formula <- function(x, data = NULL, class = NULL, cuts = NULL, subset = TRUE, lattice.options = NULL, ...)
   {
-    library(lattice)
     library(plyr)
 
-   if (!is.null(lattice.options)) {
-        oopt <- lattice.options(lattice.options)
-        on.exit(lattice.options(oopt), add = TRUE)
+    if (!is.null(lattice.options)) {
+      oopt <- lattice.options(lattice.options)
+      on.exit(lattice.options(oopt), add = TRUE)
     }
 
     formula <- x
@@ -22,48 +22,66 @@ lift <- function(x, data = NULL, class = NULL, cuts = 11, subset = TRUE, lattice
     probNames <- strsplit(form$right.name, " + ", fixed = TRUE)[[1]]
 
     liftData <- data.frame(liftClassVar = rep(form$left, length(probNames)),
-                               liftProbVar = form$right)
+                           liftProbVar = form$right)
     liftData$liftModelVar <- if(length(probNames) > 1) form$condition[[length(form$condition)]] else probNames
-   
+
+    if(is.null(cuts))
+      {
+        cuts <- if(is.null(data)) nrow(liftData) else nrow(data)
+      }
     if(length(form$condition) > 0 && any(names(form$condition) != ""))
       {
         ind <- sum(names(form$condition) != "")
         tmp <- as.data.frame(form$condition[1:ind])
         liftData <- cbind(liftData, tmp)
       }
-
     if(!is.factor(liftData$liftClassVar)) stop("the left-hand side of the formula must be a factor of classes")
 
     splitVars <- names(liftData)[!(names(liftData) %in% c("liftClassVar", "liftProbVar"))]
 
     if(is.null(class)) class <- levels(liftData$liftClassVar)[1]
-    plotData <- ddply(liftData, splitVars, liftCalc, class = class, cuts = cuts)
+    plotData <- ddply(liftData, splitVars, liftCalc, class = class, cuts = cuts)    
+    out <- list(data = plotData, cuts = cuts, class = class, probNames = probNames,
+                pct =  mean(liftData$liftClassVar == class)*100, call = match.call())
+    class(out) <- "lift"
+    out
+  }
+
+
+print.lift <- function(x, ...)
+  {
+    cat("\nCall:\n", truncateText(deparse(x$call, width.cutoff = 500)), "\n\n", sep = "")
+    cat("Models:", paste(unique(x$data$liftModelVar), collapse = ", "), "\n")
+    cat("Event: ", x$class, " (", round( x$pct, 1), "%)\n", sep = "")      
+    cat("Cuts:", x$cuts, "\n")
+    invisible(x)
+  }
+
+
+xyplot.lift <- function(x, data = NULL, ...)
+  {
     lFormula <- "cumPct ~ cuts"
     defaults <- c("liftModelVar", "cuts", "value", "resp", "n", "lift", "cumPct")
-    extras <- names(plotData)[!(names(plotData) %in% defaults)]
+    extras <- names(x$data)[!(names(x$data) %in% defaults)]
     if(length(extras) > 0) lFormula <- paste(lFormula, paste(extras, collapse = "*"), sep = "|")
 
-
     rng <- extendrange(c(0, 100))
-    if(length(probNames) > 1)
-      {
-        out <- xyplot(as.formula(lFormula), data = plotData,
-                      groups = liftModelVar,
-                      panel = panel.lift2,
-                      pct = mean(liftData$liftClassVar == class)*100,
-                      ylim = rng, xlim = rng,
-                      xlab = xlabel, ylab = ylabel,
-                      ...)
-      } else {
-        out <- xyplot(as.formula(lFormula), data = plotData,
-                      panel = panel.lift2,
-                      pct = mean(liftData$liftClassVar == class)*100,
-                      ylim = rng, xlim = rng,
-                      xlab = xlabel, ylab = ylabel,
-                      ...)
-      }
-    out
     
+    opts <- list(...)
+    if(!any(names(opts) == "xlab")) opts$xlab <- "% Samples Tested"
+    if(!any(names(opts) == "ylab")) opts$ylab <- "% Samples Found"
+    if(!any(names(opts) == "type")) opts$type <- "S"
+    if(!any(names(opts) == "ylim")) opts$ylim <- rng   
+    if(!any(names(opts) == "xlim")) opts$xlim <- rng
+    if(!any(names(opts) == "panel")) opts$panel <- panel.lift2
+    
+    args <- list(x = as.formula(lFormula),
+                 data = x$data,
+                 pct = x$pc)
+    if(length(x$probNames) > 1) args$groups <- x$data$liftModelVar
+
+    args <- c(args, opts)    
+    do.call("xyplot", args)    
   }
 
 liftCalc <- function(x, class = levels(x$liftClassVar)[1], cuts = 11)
