@@ -153,7 +153,6 @@ byComplexity <- function(x, model)
            lasso =
            {
              x[order(x$fraction),]
-
            },
            superpc =
            {
@@ -207,6 +206,9 @@ byComplexity <- function(x, model)
            {
              x[order(x$committees,  x$neighbors),]
            },
+           RRFglobal =, RRF = x[order(x$coefReg),],
+           krlsRadial = x[order(x$lambda),],
+           krlsPoly = x[order(x$degree, x$lambda),],
            xyf =, bdk = x[order(x$xdim,  x$ydim),],
            PenalizedLDA = x[order(x$lambda, x$K),],
            logreg = x[order(x$ntrees, x$treesize),],
